@@ -1,4 +1,4 @@
 from .client import Client
 
 
-__all__ = ('Client')
+__all__ = ['Client']
